@@ -2,11 +2,11 @@
 """
 @Author: HuangJingCan
 @Date: 2020-07-08 10:14:46
-@LastEditTime: 2020-07-08 11:39:59
+@LastEditTime: 2020-08-11 11:49:04
 @LastEditors: HuangJingCan
 @Description: 
 """
-from seven_top.api.base import sign
+from seven_top.top.api.base import sign
 
 
 class appinfo(object):
